==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiWidgets/QTableWidgetItem_shell.h <==
#ifndef QTABLEWIDGETITEM_SHELL_H
#define QTABLEWIDGETITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(tablewidget)
#include <QtWidgets/qtablewidget.h>
#endif //QT_CONFIG(tablewidget)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qsize.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(tablewidget)

class QTableWidgetItem_shell : public QTableWidgetItem, public QtJambiShellInterface
{
public:
    QTableWidgetItem_shell(const QIcon& icon0, const QString& text1);
    QTableWidgetItem_shell(const QString& text0);
    QTableWidgetItem_shell();
    ~QTableWidgetItem_shell() override;

    QTableWidgetItem* clone() const override;
    QVariant data(int role0) const override;
    bool operator<(const QTableWidgetItem& other0) const override;
    void read(QDataStream& in0) override;
    void setData(int role0, const QVariant& value1) override;
    void write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTableWidgetItem_access : public QTableWidgetItem
{
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_data_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0) const;
    jboolean __qt_operator_less_cref_QTableWidgetItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const;
    void __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    void __qt_setData_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0, jobject value1);
    void __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QT_CONFIG(tablewidget)
#endif // QTABLEWIDGETITEM_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QTableWidgetItem_shell.h <==
#ifndef QTABLEWIDGETITEM_SHELL_H
#define QTABLEWIDGETITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(tablewidget)
#include <QtWidgets/qtablewidget.h>
#endif //QT_CONFIG(tablewidget)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qsize.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(tablewidget)

class QTableWidgetItem_shell : public QTableWidgetItem, public QtJambiShellInterface
{
public:
    QTableWidgetItem_shell(const QIcon& icon0, const QString& text1);
    QTableWidgetItem_shell(const QString& text0);
    QTableWidgetItem_shell();
    ~QTableWidgetItem_shell() override;

    QTableWidgetItem* clone() const override;
    QVariant data(int role0) const override;
    bool operator<(const QTableWidgetItem& other0) const override;
    void read(QDataStream& in0) override;
    void setData(int role0, const QVariant& value1) override;
    void write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTableWidgetItem_access : public QTableWidgetItem
{
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_data_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0) const;
    jboolean __qt_operator_less_cref_QTableWidgetItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const;
    void __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    void __qt_setData_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0, jobject value1);
    void __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QT_CONFIG(tablewidget)
#endif // QTABLEWIDGETITEM_SHELL_H
